@@ -4,17 +4,16 @@ import logging
 import traceback
 version = "latest"
 
-from pkg_resources import Requirement, resource_filename
+#from pkg_resources import Requirement, resource_filename
 
 #READ config
 SAGA_BLISS=False
 try:
     import ConfigParser
     _CONFIG_FILE="bigjob.conf"
-    _conf_file = resource_filename(Requirement.parse("BigJob"), _CONFIG_FILE)
-    
-    if _conf_file == None or _conf_file=="":
-        _conf_file = os.path.dirname(os.path.abspath( __file__ )) + "/../" + _CONFIG_FILE
+    #_conf_file = resource_filename(_CONFIG_FILE)
+    #if _conf_file == None or _conf_file=="":
+    _conf_file = os.path.dirname(os.path.abspath( __file__ )) + "/../" + _CONFIG_FILE
     
     print "using conf file: " + str(_conf_file)
 
